#!/usr/bin/env python

__version__ = '$Revision: 4791 $'.split()[1]
__date__ = '$Date: 2007-01-02 $'.split()[1]
__author__ = 'Kurt Schwehr'

__doc__='''

List all of the AIS stations within a set of log files.

@requires: U{epydoc<http://epydoc.sourceforge.net/>} > 3.0alpha3

@author: '''+__author__+'''
@version: ''' + __version__ +'''
@var __date__: Date of last svn commit
@undocumented: __version__ __author__ __doc__ parser
@status: under development
@license: GPL
'''

import sys, os

def getStation(line, withR=False):
    fields=line.split(',')
    foundChecksum=False
    for f in fields:
	# must come after the checksum field
	if len(f)<1: continue
	if not foundChecksum:
	    if -1==f.find('*'): continue  # FIX: Is this sufficient to make sure this is a checksum?
	    #if '0'==f[0]: continue.
	    foundChecksum=True
	    continue
        if len(f)<2: continue
        if f[0] != 'r': continue
        if withR: return f
	return f[1:]
    return None

######################################################################
if __name__=='__main__':
    
	from optparse import OptionParser
	parser = OptionParser(usage="%prog [options]", version="%prog "+__version__)

	parser.add_option('-r','--without-r',dest='withR',default=True,action='store_false',
                          help='Do not keep the r in the station name')
	parser.add_option('-v','--verbose',dest='verbose',default=False,action='store_true',
                          help='Make the test output verbose')

	(options,args) = parser.parse_args()
        verbose = options.verbose

        stations = set()
	for filename in args:
	    if options.verbose: print 'Processing file:',filename
	    logfile = open(filename)
            
            for line in logfile:
                station = getStation(line,options.withR)
                if None==station: 
                    if verbose: print 'WARNING: no station for line',line
                    continue

                if verbose and station not in stations:
                    print 'New station:',station
                stations.add(station)



            if verbose:
                print 'Finished file.  Station count =',len(stations)
        for item in stations:
            print item
